==> cegui-mk2_0.5.0.orig.tar.gz: cegui_mk2/ImageCodecModules/FreeImageImageCodec/CEGUIFreeImageImageCodec.h <==
/***********************************************************************
	filename: 	CEGUIFreeImageImageCodec.h
	created:	Sun Jun 18th 2006
	author:		Andrzej Krzysztof Haczewski (aka guyver6)
	
	purpose:	This codec provide FreeImage based image loading 
*************************************************************************/
/***************************************************************************
 *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
 *
 *   Permission is hereby granted, free of charge, to any person obtaining
 *   a copy of this software and associated documentation files (the
 *   "Software"), to deal in the Software without restriction, including
 *   without limitation the rights to use, copy, modify, merge, publish,
 *   distribute, sublicense, and/or sell copies of the Software, and to
 *   permit persons to whom the Software is furnished to do so, subject to
 *   the following conditions:
 *
 *   The above copyright notice and this permission notice shall be
 *   included in all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *   OTHER DEALINGS IN THE SOFTWARE.
 ***************************************************************************/
#ifndef _CEGUIFreeImageImageCodec_h_
#define _CEGUIFreeImageImageCodec_h_
#include "CEGUIImageCodec.h"

#if defined( __WIN32__ ) || defined( _WIN32 )
#   ifdef CEGUIFREEIMAGEIMAGECODEC_EXPORTS
#       define CEGUIFREEIMAGEIMAGECODEC_API __declspec(dllexport)
#   else
#       define CEGUIFREEIMAGEIMAGECODEC_API __declspec(dllimport)
#   endif
#else
#   define CEGUIFREEIMAGEIMAGECODEC_API
#endif

// Start of CEGUI namespace section
namespace CEGUI
{
/*!
  \brief 
  Image codec based on the FreeImage library 
*/
class CEGUIFREEIMAGEIMAGECODEC_API FreeImageImageCodec : public ImageCodec 
{
public:
    FreeImageImageCodec();
    ~FreeImageImageCodec();
    
    Texture* load(const RawDataContainer& data, Texture* result);
protected:

private:

};    

} // End of CEGUI namespace section 

#endif // end of guard _CEGUIFreeImageImageCodec_h_

==> cegui-mk2_0.6.2.orig.tar.gz: cegui_mk2/ImageCodecModules/FreeImageImageCodec/CEGUIFreeImageImageCodec.h <==
/***********************************************************************
	filename: 	CEGUIFreeImageImageCodec.h
	created:	Sun Jun 18th 2006
	author:		Andrzej Krzysztof Haczewski (aka guyver6)
	
	purpose:	This codec provide FreeImage based image loading 
*************************************************************************/
/***************************************************************************
 *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
 *
 *   Permission is hereby granted, free of charge, to any person obtaining
 *   a copy of this software and associated documentation files (the
 *   "Software"), to deal in the Software without restriction, including
 *   without limitation the rights to use, copy, modify, merge, publish,
 *   distribute, sublicense, and/or sell copies of the Software, and to
 *   permit persons to whom the Software is furnished to do so, subject to
 *   the following conditions:
 *
 *   The above copyright notice and this permission notice shall be
 *   included in all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *   OTHER DEALINGS IN THE SOFTWARE.
 ***************************************************************************/
#ifndef _CEGUIFreeImageImageCodec_h_
#define _CEGUIFreeImageImageCodec_h_
#include "CEGUIImageCodec.h"

#if (defined( __WIN32__ ) || defined( _WIN32 )) && !defined(CEGUI_STATIC)
#   ifdef CEGUIFREEIMAGEIMAGECODEC_EXPORTS
#       define CEGUIFREEIMAGEIMAGECODEC_API __declspec(dllexport)
#   else
#       define CEGUIFREEIMAGEIMAGECODEC_API __declspec(dllimport)
#   endif
#else
#   define CEGUIFREEIMAGEIMAGECODEC_API
#endif

// Start of CEGUI namespace section
namespace CEGUI
{
/*!
  \brief 
  Image codec based on the FreeImage library 
*/
class CEGUIFREEIMAGEIMAGECODEC_API FreeImageImageCodec : public ImageCodec 
{
public:
    FreeImageImageCodec();
    ~FreeImageImageCodec();
    
    Texture* load(const RawDataContainer& data, Texture* result);
protected:

private:

};    

} // End of CEGUI namespace section 

#endif // end of guard _CEGUIFreeImageImageCodec_h_
